#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# This example reads in a reference molecule and a few fit
# molecules, performs overlay optimization, sorts the results
# in Tanimoto order, and shows the single best result.
# With the default options, OEOverlay optimizes both shape and color.


import sys

from openeye import oechem
from openeye import oeshape


def main(argv=[__name__]):
    overlayOpts = oeshape.OEFlexiOverlayOptions()
    opts = oechem.OERefInputAppOptions(overlayOpts, "FlexiOverlay", oechem.OEFileStringType_Mol3D,
                                       oechem.OEFileStringType_Mol3D, oechem.OEFileStringType_Mol3D, "-refmol")
    if oechem.OEConfigureOpts(opts, argv, False) == oechem.OEOptsConfigureStatus_Help:
        return 0
    overlayOpts.UpdateValues(opts)

    ifs = oechem.oemolistream()
    if not ifs.open(opts.GetInFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetInFile())

    rfs = oechem.oemolistream()
    if not rfs.open(opts.GetRefFile()):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % opts.GetRefFile())

    ofs = oechem.oemolostream()
    if not ofs.open(opts.GetOutFile()):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % opts.GetOutFile())

    refmol = oechem.OEMol()
    oechem.OEReadMolecule(rfs, refmol)
    print("Ref. Title:", refmol.GetTitle())

    overlay = oeshape.OEFlexiOverlay(overlayOpts)
    overlay.SetupRef(refmol)

    for fitmol in ifs.GetOEMols():
        results = overlay.Overlay(fitmol)
        for res, conf in zip(results, fitmol.GetConfs()):
            print("Fit Title: %-4s Tanimoto Combo: %.2f Energy: %2f"
                  % (fitmol.GetTitle(), res.GetTanimotoCombo(), res.GetInternalEnergy()))
            oechem.OESetSDData(conf, "Tanimoto Combo", "%.2f" % res.GetTanimotoCombo())
            oechem.OESetSDData(conf, "Energy", "%.2f" % res.GetInternalEnergy())
        oechem.OEWriteMolecule(ofs, fitmol)



if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict
import sys


# @ <SNIPPET-ATOM-VISIBILITY>
class OEAtomVisibilityShowRxnRole(oechem.OEUnaryAtomPred):
    def __init__(self, role):
        self.rxnrole = role
        oechem.OEUnaryAtomPred.__init__(self)

    def __call__(self, atom):
        # return True if the atom should be visible, otherwise return False
        if self.rxnrole == oechem.OERxnRole_None:
            return True
        return (self.rxnrole == atom.GetRxnRole())

    def CreateCopy(self):
        # __disown__ is required to allow C++ to take
        # ownership of this object and its memory
        return OEAtomVisibilityShowRxnRole(self.rxnrole).__disown__()


if len(sys.argv) != 3:
    oechem.OEThrow.Usage("%s <rxnfile> <imagefile>" % sys.argv[0])

ifs = oechem.oemolistream(sys.argv[1])

mol = oechem.OEGraphMol()
if not oechem.OEReadRxnFile(ifs, mol):
    oechem.OEThrow.Fatal("%s error reading reaction file" % sys.argv[0])

oedepict.OEPrepareDepiction(mol)

image = oedepict.OEImage(900, 100)

rows, cols = 1, 3
grid = oedepict.OEImageGrid(image, rows, cols)

opts = oedepict.OE2DMolDisplayOptions(grid.GetCellWidth(), grid.GetCellHeight(),
                                      oedepict.OEScale_AutoScale)

cell = grid.GetCell(1, 1)
mol.SetTitle("Reaction display")
opts.SetAtomVisibilityFunctor(oechem.OEIsTrueAtom())  # explicitly set the default
disp = oedepict.OE2DMolDisplay(mol, opts)
rxnscale = disp.GetScale()
oedepict.OERenderMolecule(cell, disp)

cell = grid.GetCell(1, 2)
mol.SetTitle("Reactant display")
opts.SetAtomVisibilityFunctor(OEAtomVisibilityShowRxnRole(oechem.OERxnRole_Reactant))
opts.SetScale(rxnscale)
disp = oedepict.OE2DMolDisplay(mol, opts)
oedepict.OERenderMolecule(cell, disp)

cell = grid.GetCell(1, 3)
mol.SetTitle("Product display")
opts.SetAtomVisibilityFunctor(OEAtomVisibilityShowRxnRole(oechem.OERxnRole_Product))
opts.SetScale(rxnscale)
disp = oedepict.OE2DMolDisplay(mol, opts)
oedepict.OERenderMolecule(cell, disp)

# @ </SNIPPET-ATOM-VISIBILITY>
oedepict.OEWriteImage(sys.argv[2], image)



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# Translates between languages.  Internally LexichemTK uses American
# English so it will convert to/from that as an intermediate
# representation.
#
# By default the program inputs/outputs the internal LexichemTK
# character set representation.  Optionally one can convert the
# input or output to alternate encodings, eg: HTML or UTF8.
#
import sys
from openeye import oechem
from openeye import oeiupac


def Translate(itf):
    ifp = sys.stdin
    if itf.GetString("-in") != "-":
        ifp = open(itf.GetString("-in"))

    if itf.HasString("-out"):
        outname = itf.GetString("-out")
        if outname != "-":
            try:
                ofs = open(outname, 'w')
            except Exception:
                oechem.OEThrow.Fatal("Unable to open '%s' for writing" % outname)
        else:
            ofs = sys.stdout

    from_language = oeiupac.OEGetIUPACLanguage(itf.GetString("-from"))
    to_language = oeiupac.OEGetIUPACLanguage(itf.GetString("-to"))

    from_charset = oeiupac.OEGetIUPACCharSet(itf.GetString("-from_charset"))
    to_charset = oeiupac.OEGetIUPACCharSet(itf.GetString("-to_charset"))

    for name in ifp:
        name = name.strip()

        # Convert from Charset to internal representation
        if from_charset == oeiupac.OECharSet_HTML:
            name = oeiupac.OEFromHTML(name)
        elif from_charset == oeiupac.OECharSet_UTF8:
            name = oeiupac.OEFromUTF8(name)

        # Translation functions all operate on lowercase names
        name = oeiupac.OELowerCaseName(name)

        if from_language != oeiupac.OELanguage_AMERICAN:
            name = oeiupac.OEFromLanguage(name, from_language)

        # At this point the name is American English in the
        # LexichemTK default internal character representation

        # Convert to output language
        if to_language != oeiupac.OELanguage_AMERICAN:
            name = oeiupac.OEToLanguage(name, to_language)

        # Convert to output charset
        if to_charset == oeiupac.OECharSet_ASCII:
            name = oeiupac.OEToAscii(name)
        elif to_charset == oeiupac.OECharSet_UTF8:
            name = oeiupac.OEToUTF8(name)
        elif to_charset == oeiupac.OECharSet_HTML:
            name = oeiupac.OEToHTML(name)
        elif to_charset == oeiupac.OECharSet_SJIS:
            name = oeiupac.OEToSJIS(name)
        elif to_charset == oeiupac.OECharSet_EUCJP:
            name = oeiupac.OEToEUCJP(name)

        ofs.write(name + '\n')


############################################################
InterfaceData = """
# translate interface file
!CATEGORY translate

      !PARAMETER -in 1
        !ALIAS -i
        !TYPE string
        !REQUIRED true
        !BRIEF Input filename
        !KEYLESS 1
      !END

      !PARAMETER -out 2
        !ALIAS -o
        !TYPE string
        !DEFAULT -
        !BRIEF Output filename
        !KEYLESS 2
      !END

      !PARAMETER -from 3
         !ALIAS -from_language
         !TYPE string
         !DEFAULT american
         !LEGAL_VALUE american
         !LEGAL_VALUE english
         !LEGAL_VALUE us

         !LEGAL_VALUE chinese
         !LEGAL_VALUE zh
         !LEGAL_VALUE cn

         !LEGAL_VALUE danish
         !LEGAL_VALUE dk
         !LEGAL_VALUE da

         !LEGAL_VALUE dutch
         !LEGAL_VALUE nl

         !LEGAL_VALUE french
         !LEGAL_VALUE fr

         !LEGAL_VALUE german
         !LEGAL_VALUE de

         !LEGAL_VALUE greek
         !LEGAL_VALUE el

         !LEGAL_VALUE hungarian
         !LEGAL_VALUE hu

         !LEGAL_VALUE irish
         !LEGAL_VALUE ie
         !LEGAL_VALUE ga

         !LEGAL_VALUE italian
         !LEGAL_VALUE it

         !LEGAL_VALUE japanese
         !LEGAL_VALUE jp
         !LEGAL_VALUE ja

         !LEGAL_VALUE polish
         !LEGAL_VALUE pl

         !LEGAL_VALUE portuguese
         !LEGAL_VALUE pt

         !LEGAL_VALUE romanian
         !LEGAL_VALUE ro

         !LEGAL_VALUE russian
         !LEGAL_VALUE ru

         !LEGAL_VALUE slovak
         !LEGAL_VALUE sk

         !LEGAL_VALUE spanish
         !LEGAL_VALUE es

         !LEGAL_VALUE swedish
         !LEGAL_VALUE se
         !LEGAL_VALUE sv

         !LEGAL_VALUE welsh
         !LEGAL_VALUE cy

         !REQUIRED false
         !BRIEF Language for input names.
     !END

     !PARAMETER -to 4
         !ALIAS -to_language
         !TYPE string
         !DEFAULT american
         !LEGAL_VALUE american
         !LEGAL_VALUE english
         !LEGAL_VALUE us

         !LEGAL_VALUE chinese
         !LEGAL_VALUE zh
         !LEGAL_VALUE cn

         !LEGAL_VALUE danish
         !LEGAL_VALUE dk
         !LEGAL_VALUE da

         !LEGAL_VALUE dutch
         !LEGAL_VALUE nl

         !LEGAL_VALUE french
         !LEGAL_VALUE fr

         !LEGAL_VALUE german
         !LEGAL_VALUE de

         !LEGAL_VALUE greek
         !LEGAL_VALUE el

         !LEGAL_VALUE hungarian
         !LEGAL_VALUE hu

         !LEGAL_VALUE irish
         !LEGAL_VALUE ie
         !LEGAL_VALUE ga

         !LEGAL_VALUE italian
         !LEGAL_VALUE it

         !LEGAL_VALUE japanese
         !LEGAL_VALUE jp
         !LEGAL_VALUE ja

         !LEGAL_VALUE polish
         !LEGAL_VALUE pl

         !LEGAL_VALUE portuguese
         !LEGAL_VALUE pt

         !LEGAL_VALUE romanian
         !LEGAL_VALUE ro

         !LEGAL_VALUE russian
         !LEGAL_VALUE ru

         !LEGAL_VALUE slovak
         !LEGAL_VALUE sk

         !LEGAL_VALUE spanish
         !LEGAL_VALUE es

         !LEGAL_VALUE swedish
         !LEGAL_VALUE se
         !LEGAL_VALUE sv

         !LEGAL_VALUE welsh
         !LEGAL_VALUE cy

         !REQUIRED false
         !BRIEF Language for input names.
     !END

     !PARAMETER -from_charset 5
         !TYPE string
         !DEFAULT default
         !REQUIRED false
         !LEGAL_VALUE default
         !LEGAL_VALUE ascii
         !LEGAL_VALUE utf8
         !LEGAL_VALUE html
         !LEGAL_VALUE sjis
         !LEGAL_VALUE eucjp
         !BRIEF Choose charset/encoding for input names.
     !END

     !PARAMETER -to_charset 6
         !ALIAS -encoding
         !ALIAS -charset
         !TYPE string
         !DEFAULT default
         !REQUIRED false
         !LEGAL_VALUE default
         !LEGAL_VALUE ascii
         !LEGAL_VALUE utf8
         !LEGAL_VALUE html
         !LEGAL_VALUE sjis
         !LEGAL_VALUE eucjp
         !BRIEF Choose charset/encoding for output names.
     !END


!END
"""


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)
    Translate(itf)


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "C1CCCCC1O")
oedepict.OEPrepareDepiction(mol)

width, height = 400, 200
image = oedepict.OEImage(width, height)


# @ <SNIPPET-USER-DEF-BOND-MARKUP>
class UserDataSVGBondIdxMarkup(oedepict.OEBondSVGMarkupBase):
    def GetClassName(self, bond):
        return "user-def-bond-class"

    def GetGroupId(self, bond):
        return "user-def-bond-{}".format(bond.GetIdx())

    def CreateCopy(self):
        return UserDataSVGBondIdxMarkup().__disown__()


opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)
opts.SetBondSVGMarkupFunctor(UserDataSVGBondIdxMarkup())
disp = oedepict.OE2DMolDisplay(mol, opts)

# @ </SNIPPET-USER-DEF-BOND-MARKUP>

oedepict.OERenderMolecule(image, disp)
oedepict.OEWriteImage("UserBondMarkup.svg", image)



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Extract the ring scaffold of a molecule
#############################################################################
from openeye import oechem
try:
    set()
except NameError:
    from sets import Set as set
import sys


def TraverseForRing(visited, atom):
    visited.add(atom.GetIdx())

    for nbor in atom.GetAtoms():
        if nbor.GetIdx() not in visited:
            if nbor.IsInRing():
                return True

            if TraverseForRing(visited, nbor):
                return True

    return False


def DepthFirstSearchForRing(root, nbor):
    visited = set()
    visited.add(root.GetIdx())

    return TraverseForRing(visited, nbor)


class IsInScaffold(oechem.OEUnaryAtomPred):
    def __call__(self, atom):
        if atom.IsInRing():
            return True

        count = 0
        for nbor in atom.GetAtoms():
            if DepthFirstSearchForRing(atom, nbor):
                count += 1

        return count > 1


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    exo_dbl_bonds = itf.GetBool("-exo")

    ifs = oechem.oemolistream()
    if not ifs.open(itf.GetString("-i")):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % itf.GetString("-i"))

    ofs = oechem.oemolostream()
    if not ofs.open(itf.GetString("-o")):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % itf.GetString("-o"))

    for src in ifs.GetOEMols():
        dst = oechem.OEMol()
        pred = IsInScaffold()
        if exo_dbl_bonds:
            pred = oechem.OEOrAtom(pred, oechem.OEIsNonRingAtomDoubleBondedToRing())

        adjustHcount = True
        oechem.OESubsetMol(dst, src, pred, adjustHcount)

        if dst.IsValid():
            oechem.OEWriteMolecule(ofs, dst)


InterfaceData = """
!BRIEF [-exo] [-i] <input> [-o] <scaffolds>
!PARAMETER -i
  !ALIAS -in
  !TYPE string
  !REQUIRED true
  !BRIEF input file name
  !KEYLESS 1
!END
!PARAMETER -o
  !ALIAS -out
  !TYPE string
  !REQUIRED true
  !BRIEF output file name
  !KEYLESS 2
!END
!PARAMETER -exo
  !TYPE bool
  !DEFAULT true
  !BRIEF Exclude double bonds exo to ring in scaffold
!END
"""

if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2022 Cadence Design Systems, Inc. (Cadence) 
# All rights reserved.
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of Cadence products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. Cadence claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable Cadence offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall Cadence be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import os
import sys

try:
    from xmlrpclib import ServerProxy
except ImportError:  # python 3
    from xmlrpc.client import ServerProxy

from openeye import oechem

oepy = os.path.join(os.path.dirname(__file__), "..", "python")
sys.path.insert(0, os.path.realpath(oepy))

InterfaceData = """\
!BRIEF (-debug|-verbose|-info|-warning|-error) [-h] <server:port>
!PARAMETER -host
  !ALIAS -h
  !TYPE string
  !REQUIRED true
  !BRIEF The host whose verbosity level will be changed
  !KEYLESS 1
!END
!PARAMETER -debug
  !ALIAS -d
  !TYPE bool
  !DEFAULT false
  !BRIEF Debug error level
!END
!PARAMETER -verbose
  !ALIAS -v
  !TYPE bool
  !DEFAULT false
  !BRIEF Verbose error level
!END
!PARAMETER -info
  !ALIAS -i
  !TYPE bool
  !DEFAULT false
  !BRIEF Info error level
!END
!PARAMETER -warning
  !ALIAS -w
  !TYPE bool
  !DEFAULT false
  !BRIEF Warning error level
!END
!PARAMETER -error
  !ALIAS -e
  !TYPE bool
  !DEFAULT false
  !BRIEF Unrecoverable error level
!END
"""


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    levels = {"-debug": (oechem.OEErrorLevel_Debug,   "oechem.OEErrorLevel_Debug"),
              "-verbose": (oechem.OEErrorLevel_Verbose, "oechem.OEErrorLevel_Verbose"),
              "-info": (oechem.OEErrorLevel_Info,    "oechem.OEErrorLevel_Info"),
              "-warning": (oechem.OEErrorLevel_Warning, "oechem.OEErrorLevel_Warning"),
              "-error": (oechem.OEErrorLevel_Error,   "oechem.OEErrorLevel_Error")}

    onFlags = [key for key in levels if itf.GetBool(key)]
    if not onFlags:
        oechem.OEThrow.Fatal("Need specify exactly one error level: " +
                             "|".join(levels.keys()))
    elif len(onFlags) > 1:
        oechem.OEThrow.Fatal("This flags are mutually exclusive: " +
                             "|".join(onFlags))

    level, name = levels[onFlags[0]]

    s = ServerProxy("http://" + itf.GetString("-host"))
    if s.OEThrowSetLevel(level):
        print("oechem.OEThrow.SetLevel(" + name + ") successful")
    else:
        print("oechem.OEThrow.SetLevel(" + name + ") failed")

    return 0


if __name__ == '__main__':
    sys.exit(main(sys.argv))
